# Visibility

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**default_visibility** | **bool** |  | [optional] 
**exceptions** | [**list[Component]**](Component.md) |  | [optional] 
**view_setup_hints** | [**ViewSetupHints**](ViewSetupHints.md) |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


